Get indices of starts and ends of runs of duplicate values
get_dup_run_inds(dups)named list with entries starts giving indices of the first element
in each sequence of runs of duplicate values and ends giving indices of
the last element in each sequence of runs of duplicate values.
a boolean vector that would result from calling
duplicated_tol(..., incl_first = FALSE)